@@ -225,9 +225,7 @@ def leaves(dir_or_file, allow_symlinks = True, ignore_hidden_file = True):
     '''
     # Check sanity
     if not os.path.exists(dir_or_file):
-        raise Usage(' '.join([source_dir, 'does not exist']))
-
-
+        raise Usage(' '.join([dir_or_file, 'does not exist']))
 
     # Base case
     if os.path.isfile(dir_or_file) and not dir_or_file.startswith('.'):
